@@ -1,12 +1,11 @@
 package File::Collector ;
-$File::Collector::VERSION = '0.025';
+$File::Collector::VERSION = '0.026';
 use strict; use warnings;
 
 use Carp;
 use File::Spec;
 use File::Basename;
 use Role::Tiny::With;
-use Log::Log4perl::Shortcuts qw(:all);
 
 # public methods
 
@@ -428,7 +427,7 @@ File::Collector - Base class for custom File::Collector classes for classifying
 
 =head1 VERSION
 
-version 0.025
+version 0.026
 
 =head1 OVERVIEW
 
@@ -800,8 +799,6 @@ and the file name of the file being processed or in an iterator.
 
 =item * L<File::Spec|File::Spec>
 
-=item * L<Log::Log4perl::Shortcuts|Log::Log4perl::Shortcuts>
-
 =item * L<Role::Tiny::With|Role::Tiny::With>
 
 =item * L<strict|strict>
